from distutils.core import setup

setup(
    name = 'MoneyCraft',
    packages = ['moneycraft'],
    scripts = [],
    version = '1.0.2',
    description = 'A python quant platform for financial use.',
    author = 'austin362667',
    author_email = 'austin362667@gmail.com',
    url = 'https://github.com/austin362667/MonyCraft',
    download_url = 'https://github.com/austin362667/MonyCraft.git',
    keywords = ['finance', 'backtest', 'quant'],
    classifiers = []
)